Workflow — collective.conferences 0.2 documentation

# Workflow

The content objects are assigned to the default ‘Simple Publication Workflow’ with the exeption of conference talks and workshops. They have their own workflows.

## Simple Publication Workflow

The default state of this content objects is ‘private’. The owner (creator) of this object could submit it for publication. This changes the state to pending and will forwarded to the review queue.

If the user want to reedit the content object, she/he could ‘retract’ it. The state changes back to ‘private’.

If a reviewer think the content object is not ready for publication and the user (creator) should rework (edit or make additions), she/he could ‘send back’ the content object to the user.

If the content object is ready for publication the reviewer could ‘publish’ it.

There is also an ‘advanced’ option for the reviewer. She/he could use it to add some notes to her/his action (e.g. send the content object back with some notes to the creator) or set a publication date or/ and the expiration date.

## Conference Talk Publication Workflow

The conference talk object are assigned to the conference talk publication workflow. This workflow currently differs from the simple publication workflow only in regard to its default state. Every conference talk get the default state ‘pending’. Thus the talk will be forwarded after its creation to the review queue.

## Conference Workshop Publication Workflow

The conference workshop objects are assigned to the conference workshop publication workflow. There is currently no difference to the process of the conference talk publication workflow (see above).